import 'dart:io';

import 'package:tiga/src/context/httpContext.dart';
import 'package:tiga/src/context/httpRequestFeature.dart';
import 'package:tiga/src/context/httpResponseFeature.dart';
import 'package:tiga/src/delegate/requestDelegate.dart';
import 'package:tiga/src/server/serverAbstract.dart';



class HttpListenerServer implements ServerAbstract {
  HttpServer _httpServer;
  String _address;
  int _port;

  HttpListenerServer(String address, int port) {
    _address = address;
    _port = port;
  }

  @override
  Future runAsync(RequestDelegate handler) async {
    _httpServer = await HttpServer.bind(_address, _port);
    print("[Info]: Server started and is listening on:$_address:$_port");
    _httpServer.listen((request) => {_handleRequest(request, handler)});
  }

  _handleRequest(HttpRequest request, RequestDelegate handler) {
    Map<String,String> _headers={};
    request.headers.forEach((k, v) {
      if(v.length>0){
        _headers[k] = v.join(",");
      }

    });
    _headers.remove(HttpHeaders.transferEncodingHeader);
    HttpRequestFeature requestFeature =
        HttpRequestFeature(request.uri, _headers, request);

    HttpResponseFeature responseFeature = HttpResponseFeature(request.response);

    HttpContext httpContext = HttpContext(requestFeature, responseFeature);
    handler(httpContext);
    request.response.close();
  }


}
