import 'package:tiga/src/applicationBuilder/applicationBuilder.dart';
import 'package:tiga/src/middleware/middleware.dart';
import 'package:tiga/src/server/httpListenerServer.dart';
import 'package:tiga/src/server/serverAbstract.dart';
import 'package:tiga/src/webHost/webHost.dart';
import 'package:tiga/src/webHost/webHostAbstract.dart';
import 'package:tiga/src/webHost/webHostBuilderAbstract.dart';

class WebHostBuilder implements WebHostBuilderAbstract {
  ServerAbstract _server;
  List<Middleware> _middlewares = [];

  @override
  WebHostAbstract build() {
    var builder = ApplicationBuilder();
    _middlewares.forEach((middleware) {
      builder.use(middleware);
    });
    return WebHost(_server, builder.build());
  }

  @override
  WebHostBuilderAbstract useServer(HttpListenerServer server) {
    _server = server;
    return this;
  }

  WebHostBuilderAbstract useHttpListener(String address, int port) =>
      this.useServer(new HttpListenerServer(address, port));

  @override
  WebHostBuilderAbstract addMiddleware(Middleware middleware) {
    _middlewares.add(middleware);
    return this;
  }
}
